@@ -4,7 +4,7 @@ use v5.10;
 use strict;
 # use warnings;
 $^W = 0;
-our $VERSION = "1.33";
+our $VERSION = "1.34";
 
 my ($GinFile, $GpageObjNr, $GrootNr, $Gpos, $GobjNr, $Gstream, $GoWid, $GoHei);
 my (@Gkids, @Gcounts, @GmediaBox, @Gobject, @Gparents, @Gto_be_created);
@@ -50,51 +50,51 @@ sub main {
 
   # Paper surfaces in square pts (expressed as HxW in points):
   %Gpaper = (
-    QuarterLetter => $FH*$FW, # =   121_176
-    A6            => $CH*$CW, # ~   124_867
-    QuarterLegal  => $IH*$IW, # =   154_224
-    HalfLetter    => $EH*$EW, # =   242_352
-    A5            => $BH*$BW, # ~   249_735
-    HalfLegal     => $HH*$HW, # =   308_448
-    Letter        => $DH*$DW, # =   484_704
-    A4            => $AH*$AW, # ~   501_156
-    Legal         => $GH*$GW, # =   616_896
-    Tabloid       => $KH*$KW, # =   969_408
-    A3            => $JH*$JW, # ~ 1_002_312
+    QuarterLetter => $FH * $FW, # =   121_176
+    A6            => $CH * $CW, # ~   124_867
+    QuarterLegal  => $IH * $IW, # =   154_224
+    HalfLetter    => $EH * $EW, # =   242_352
+    A5            => $BH * $BW, # ~   249_735
+    HalfLegal     => $HH * $HW, # =   308_448
+    Letter        => $DH * $DW, # =   484_704
+    A4            => $AH * $AW, # ~   501_156
+    Legal         => $GH * $GW, # =   616_896
+    Tabloid       => $KH * $KW, # =   969_408
+    A3            => $JH * $JW, # ~ 1_002_312
   );
 
   # Page reordering and position offset schemas for "4 up":
   my @P_4UP_13PLUS = (16,1,13,4,2,15,3,14,12,5,9,8,6,11,7,10);
-  my @P_4UP_9PLUS = (12,1,9,4,2,11,3,10,6,7,9999,9999,8,5);
-  my @P_4UP_5PLUS = (8,1,5,4,2,7,3,6);
-  my @P_4UP_1PLUS = (4,1,9999,9999,2,3);
-  my @X_A6_ON_A4 = (000,$CW,$CW,$AW,000,$CW,$CW,$AW,000,$CW,$CW,$AW,000,$CW,$CW,$AW);
-  my @Y_A6_ON_A4 = ($CX,$CX,$CH,$CH,$CX,$CX,$CH,$CH,$CX,$CX,$CH,$CH,$CX,$CX,$CH,$CH);
-  my @X_QT_ON_LT = (000,$FW,$FW,$DW,000,$FW,$FW,$DW,000,$FW,$FW,$DW,000,$FW,$FW,$DW);
-  my @Y_QT_ON_LT = ($FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH,$FH);
-  my @X_QG_ON_LG = (000,$IW,$IW,$GW,000,$IW,$IW,$GW,000,$IW,$IW,$GW,000,$IW,$IW,$GW);
-  my @Y_QG_ON_LG = ($IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH,$IH);
+  my @P_4UP_9PLUS  = (12,1,9,4,2,11,3,10,6,7,9999,9999,8,5);
+  my @P_4UP_5PLUS  = (8,1,5,4,2,7,3,6);
+  my @P_4UP_1PLUS  = (4,1,9999,9999,2,3);
+  my @X_A6_ON_A4 = (000,$CW,$CW,$AW) x 4;
+  my @Y_A6_ON_A4 = ($CX,$CX,$CH,$CH) x 4;
+  my @X_QT_ON_LT = (000,$FW,$FW,$DW) x 4;
+  my @Y_QT_ON_LT = ($FH,$FH,$FH,$FH) x 4;
+  my @X_QG_ON_LG = (000,$IW,$IW,$GW) x 4;
+  my @Y_QG_ON_LG = ($IH,$IH,$IH,$IH) x 4;
 
   # Page reordering and position offset schemas for "2 up":
   my @P_2UP_13PLUS = (1,16,2,15,3,14,4,13,5,12,6,11,7,10,8,9);
-  my @P_2UP_9PLUS = (1,12,2,11,3,10,4,9,5,8,6,7);
-  my @P_2UP_5PLUS = (1,8,2,7,3,6,4,5);
-  my @P_2UP_1PLUS = (1,4,2,3);
-  my @X_A5_ON_A4 = ($BH,$BH,000,000,$BH,$BH,000,000,$BH,$BH,000,000,$BH,$BH,000,000);
-  my @Y_A5_ON_A4 = ($BX,000,$AH,$BX,$BX,000,$AH,$BX,$BX,000,$AH,$BX,$BX,000,$AH,$BX);
-  my @X_HT_ON_LT = ($EH,$EH,000,000,$EH,$EH,000,000,$EH,$EH,000,000,$EH,$EH,000,000);
-  my @Y_HT_ON_LT = ($EW,000,$DH,$EW,$EW,000,$DH,$EW,$EW,000,$DH,$EW,$EW,000,$DH,$EW);
-  my @X_HG_ON_LG = ($HH,$HH,000,000,$HH,$HH,000,000,$HH,$HH,000,000,$HH,$HH,000,000);
-  my @Y_HG_ON_LG = ($HW,000,$GH,$HW,$HW,000,$GH,$HW,$HW,000,$GH,$HW,$HW,000,$GH,$HW);
-  my @X_LT_ON_TA = ($DH,$DH,000,000,$DH,$DH,000,000,$DH,$DH,000,000,$DH,$DH,000,000);
-  my @Y_LT_ON_TA = ($DW,000,$KH,$DW,$DW,000,$KH,$DW,$DW,000,$KH,$DW,$DW,000,$KH,$DW);
-  my @X_A4_ON_A3 = ($AH,$AH,000,000,$AH,$AH,000,000,$AH,$AH,000,000,$AH,$AH,000,000);
-  my @Y_A4_ON_A3 = ($AW,000,$JH,$AW,$AW,000,$JH,$AW,$AW,000,$JH,$AW,$AW,000,$JH,$AW);
+  my @P_2UP_9PLUS  = (1,12,2,11,3,10,4,9,5,8,6,7);
+  my @P_2UP_5PLUS  = (1,8,2,7,3,6,4,5);
+  my @P_2UP_1PLUS  = (1,4,2,3);
+  my @X_A5_ON_A4 = ($BH,$BH,000,000) x 4;
+  my @Y_A5_ON_A4 = ($BX,000,$AH,$BX) x 4;
+  my @X_HT_ON_LT = ($EH,$EH,000,000) x 4;
+  my @Y_HT_ON_LT = ($EW,000,$DH,$EW) x 4;
+  my @X_HG_ON_LG = ($HH,$HH,000,000) x 4;
+  my @Y_HG_ON_LG = ($HW,000,$GH,$HW) x 4;
+  my @X_LT_ON_TA = ($DH,$DH,000,000) x 4;
+  my @Y_LT_ON_TA = ($DW,000,$KH,$DW) x 4;
+  my @X_A4_ON_A3 = ($AH,$AH,000,000) x 4;
+  my @Y_A4_ON_A3 = ($AW,000,$JH,$AW) x 4;
 
   my ($inpPgNum, $inpPgSize);
   my $numPagImposed = 0;
   my $sayUsage = "Usage: paperback file.pdf (will produce 'file-paperback.pdf').";
-  my $sayVersion = "This is paperback v${VERSION}, (c) 2022 Hector M. Monacci.";
+  my $sayVers = "This is paperback v${VERSION}, (c) 2022 Hector M. Monacci.";
   my $sayHelp = <<"END_MESSAGE";
 ${sayUsage}
 
@@ -137,13 +137,13 @@ ANSI normalised (US) page sizes:
 
 For further details, please try 'perldoc paperback'.
 
-${sayVersion}
+${sayVers}
 END_MESSAGE
 
   die "[!] ${sayUsage}\n" if ! defined $input;
-  do {print STDERR "${sayHelp}" and exit}
+  do {print STDERR "${sayHelp}"; exit} 
     if $input =~ "^-h\$" or $input =~ "^--help\$";
-  do {print STDERR "${sayVersion}\n" and exit}
+  do {print STDERR "${sayVers}\n"; exit} 
     if $input =~ "^-v\$" or $input =~ "^--version\$";
   ($inpPgNum, $inpPgSize) = openInputFile($input);
 
@@ -157,7 +157,7 @@ END_MESSAGE
     elsif ($_ eq "HG") { $pgPerOutputPage = 2; @x = @X_HG_ON_LG; @y = @Y_HG_ON_LG; }
     elsif ($_ eq "LT") { $pgPerOutputPage = 2; @x = @X_LT_ON_TA; @y = @Y_LT_ON_TA; }
     elsif ($_ eq "A4") { $pgPerOutputPage = 2; @x = @X_A4_ON_A3; @y = @Y_A4_ON_A3; }
-    else {die "[!] Bad page size (${inpPgSize}). Try 'paperback -h' for more info.\n"}
+    else {die "[!] Bad page size (${_}). Try 'paperback -h' for more info.\n"}
   }
 
   my ($name) = $input =~ /(.+)\.[^.]+$/;
